<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       www.orionorigin.com
 * @since      1.0.0
 *
 * @package    Vpc_Sci
 * @subpackage Vpc_Sci/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Vpc_Sci
 * @subpackage Vpc_Sci/public
 * @author     ORION <support@orionorigin.com>
 */
class Vpc_Sci_Public
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of the plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{
		$this->plugin_name = $plugin_name;
		$this->version     = $version;
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{
		wp_enqueue_style('vpc-sci-public-css', plugin_dir_url(__FILE__) . 'css/vpc-sci-public.css', array(), VPC_SCI_VERSION, 'all');
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{
		wp_enqueue_script('vpc-sci-public-js', plugin_dir_url(__FILE__) . 'js/vpc-sci-public.js', array('jquery'), VPC_SCI_VERSION, false);
		wp_localize_script('vpc-sci-public-js', 'ajax_object', array('ajaxurl' => admin_url('admin-ajax.php')));
	}

	/**
	 * Function to get save preview button.
	 *
	 * @param array $buttons    vpc buttons array.
	 * @param int   $prod_id   Product id.
	 * @return string
	 */
	public function add_save_button($buttons, $prod_id)
	{
		if (!get_option('vpc-save-custom-image-add-on-license-key')) {
			echo "<h2 class='error_msg'>You have not activated your license yet. Please, activate it in order to use Save configurator add on.</h2>";
		} else {
			$config = $this->get_vpc_sci_config_data($prod_id);
			if (isset($config['save-config']) && 'Yes' === $config['save-config']) {
				$save_config_btn = array(
					'id'         => 'vpc-save-config',
					'label'      => __('Download Image', 'vpc-sci'),
					'class'      => 'vpc-save',
					'attributes' => array(
						'data-pid' => $prod_id,
					),
				);
				$save_config_btn = apply_filters('vpc_download_img_btn', $save_config_btn, $prod_id);
				array_push($buttons, $save_config_btn);
?>
				<div class="download_container">
					<a id="save-preview-img" href="" class="vpc-save-img" download></a>
				</div>
<?php
			}
		}
		return $buttons;
	}

	/**
	 * Fonction to get configuration datas.
	 *
	 * @param string $prod_id product id.
	 * @return array
	 */
	private function get_vpc_sci_config_data($prod_id)
	{
		$ids         = get_product_root_and_variations_ids($prod_id);
		$config_meta = get_post_meta($ids['product-id'], 'vpc-config', true);
		$configs     = get_proper_value($config_meta, $prod_id, array());
		$config_id   = get_proper_value($configs, 'config-id', false);
		$config      = get_post_meta($config_id, 'vpc-config', true);
		return $config;
	}


	/**
	 * Function to save preview output canvas image in server.
	 */
	public function sci_save_canvas_img_in_server()
	{
		wp_verify_nonce('save_sci_canvas_img', 'save_canvas_img_nonce');
		$recap                         = array();
		$multiview                     = '';
		$custom_vars                   = '';
		$imgs_by_views                 = array();

		if (isset($_POST['recap'])) {
			$sanitize_recap = vpc_sci_sanitize_array(wp_unslash($_POST['recap']));
			$recap          = vpc_sci_clean_recap($sanitize_recap);
		}

		if (isset($_POST['imgs_by_views'])) {
			$imgs_by_views = vpc_sci_sanitize_array(wp_unslash($_POST['imgs_by_views']));
		}

		if (isset($_POST['multiview']) && !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['multiview'])))) {
			$multiview = sanitize_text_field(wp_unslash($_POST['multiview']));
		}

		if (isset($_POST['custom_vars']) && !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['custom_vars'])))) {
			$custom_vars =  $_POST['custom_vars'];
		}

		// Remove empty compenents.
		if (isset($recap) && !empty($recap)) {
			foreach ($recap as $key => $value) {
				if ('' === $value) {
					unset($recap[$key]);
				}
			}
		}
		$preview_url = '';
		$preview_url = vpc_get_merged_image($custom_vars, $multiview);
		echo wp_json_encode($preview_url);
		die();
	}

	/**
	 * Function to save preview.
	 */
	public function save_vpc_sci_preview()
	{
		wp_verify_nonce('vpc_sci_save_preview', 'vpc_save_preview_nonce');
		$prod_id       = '';
		$multiview     = '';
		$preview_saved = array();

		if (isset($_POST['prod_id']) && !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['prod_id'])))) {
			$prod_id = sanitize_text_field(wp_unslash($_POST['prod_id']));
		}

		if (isset($_POST['multiview']) && !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['multiview'])))) {
			$multiview = sanitize_text_field(wp_unslash($_POST['multiview']));
		}

		if (isset($_POST['preview_saved']) && !wp_verify_nonce(sanitize_text_field(wp_unslash($_POST['preview_saved'])))) {
			$previews = sanitize_text_field(wp_unslash($_POST['preview_saved']));
			$previews = json_decode(stripslashes($previews));
			if (class_exists('Vpc_Mva') && 'true' === $multiview) {
				foreach ($previews as $view => $url) {
					$preview_saved[$view] = $url;
				}
			} else {
				$preview_saved[0] = $previews;
			}
		}

		$config_id = get_product_config($prod_id)->id;
		$name      = sanitize_file_name(get_the_title($config_id)) . '_' . uniqid();
		$links     = array(
			'url'  => $preview_saved,
			'name' => $name,
		);
		echo wp_json_encode($links);
		die();
	}

	/**
	 * Save preview output variable.
	 *
	 * @param array $datas  all datas for configuration.
	 * @return array
	 */
	public function sci_vars($datas)
	{
		$config                     = $this->get_vpc_sci_config_data($datas['product']);
		$datas['multiviews_option'] = get_proper_value($config, 'multi-views', 'No');
		$datas['require_fields'] = get_proper_value($config, 'require-fields', 'Yes');
		return $datas;
	}
}
